sshtunnel

package
v0.3.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 16, 2021 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ConnectLocalPortToRemotePort

func ConnectLocalPortToRemotePort(
	localPort string,
	remoteAdress string,
	remotePort string,
	sshName string,
) runmanager.Service

ConnectLocalPortToRemotePort starts a service which connects the local host with the remote host on the given ports.

func ConnectRemotePortToLocalPort

func ConnectRemotePortToLocalPort(
	remoteAdress string,
	remotePort string,
	localPort string,
	sshName string,
) runmanager.Service

ConnectLocalPortToRemotePort starts a service which connects the remote host with the local host on the given ports.

Types

This section is empty.

Source Files

  • connect-local-to-remote-port.go
  • connect-remote-ports.go

Directories

Path Synopsis
Package runs ssh tunnels.
Package runs ssh tunnels.

Jump to